"""
Basic field monitor example

Change the fm_address variable to match your FM7004.

You can use PyVISA to get a list of available resources:
import visa
rm = visa.ResourceManager()
print(rm.list_resources())
"""

import time
from ardrivers import arfieldprobe

fm_address = 'GPIB0::5::INSTR'

# Create an AR_FieldMonitor object and initialize the VISA session
fm = arfieldprobe.AR_FieldMonitor()
fm.initialize(fm_address)
print('*IDN:', fm.id_query())

# Configure the display to XYZ mode
fm.config_display_mode(arfieldprobe.AR_FieldMonitor.DisplayMode.XYZ)

# Enable internal frequency correction and set the frequency
fm.config_frequency_correction(True)
fm.set_frequency(80e6)

# Turn on channel 1
fm.config_channel_state(1, True)
time.sleep(1)

# Get information about the attached probe
probe_id = fm.query_probe_status(1)
print('Probe on channel 1:')
print('Model:', probe_id['model'])
print('Serial Number:', probe_id['serial'])
print('Firmware revision:', probe_id['firmware'])

# Configure the channel
fm.config_axes(1, 1, 1, 1)
fm.config_sample_rate(1, 25)

# Read data from the probe
data = fm.read_data(1)
print('X:', data['x'])
print('Y:', data['y'])
print('Z:', data['z'])
print('Composite:', data['c'])

# Return the FM7004 to local mode and close the VISA session
fm.local_mode()
fm.close()
